==> haskell-feed-1.0.0.0-108-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.0.0.0
id: feed-1.0.0.0-H075bPrtmao1lgjjg0fyS1
key: feed-1.0.0.0-H075bPrtmao1lgjjg0fyS1
license: BSD-3-Clause
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Sigbjorn Finne <sof@forkIO.com>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
abi: b95782cf832814a49cbbb648adc5295b
exposed: True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/feed-1.0.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/feed-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.0.0.0-H075bPrtmao1lgjjg0fyS1
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur text-1.2.3.0 time-1.8.0.2
    time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    xml-conduit-1.8.0-ClPAq0dG1498wzBxsM2y76
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=cfb34821984e3d96e729b0bde52e0e35
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg=8e7cbe9859e6b2fba2bf52bd3dee4d4a
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=d60c5437db670e030567a6d42bb218af
             xml-conduit-1.8.0-ClPAq0dG1498wzBxsM2y76=41267f521aceec33a49b8d0364e915c4
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-feed-1.0.0.0-109-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.0.0.0
id: feed-1.0.0.0-47iaa950w6q83bwRF4AS5h
key: feed-1.0.0.0-47iaa950w6q83bwRF4AS5h
license: BSD-3-Clause
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Sigbjorn Finne <sof@forkIO.com>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
abi: 5296d0de923593c4541fc05aae2c2815
exposed: True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/feed-1.0.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/feed-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.0.0.0-47iaa950w6q83bwRF4AS5h
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur text-1.2.3.0 time-1.8.0.2
    time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=cfb34821984e3d96e729b0bde52e0e35
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg=8e7cbe9859e6b2fba2bf52bd3dee4d4a
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=d60c5437db670e030567a6d42bb218af
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
